@@ -1,7 +1,5 @@
 from datetime import datetime, timedelta
 from .objectJSON import ObjectJSON
-from .request.numero_doc import NumeroDoc
-from .numeroDoc import NossoNumero
 
 
 class Boleto(ObjectJSON):
@@ -9,6 +7,7 @@ class Boleto(ObjectJSON):
     def __init__(self, titulo, cedente, mensagem, prazo_baixa):
         self.idintegracao = None
         self.situacao = None
+        self.body = None
         #sacado
         self.SacadoCPFCNPJ = None
         self.SacadoNome = None
@@ -31,9 +30,8 @@ class Boleto(ObjectJSON):
         self.CedenteConvenioNumero = str(cedente['CedenteConvenioNumero'])
 
         #titulo
-        numerodoc = NossoNumero().gerar_nossonumero()
-        self.TituloNossoNumero = str(numerodoc)
-        self.TituloNumeroDocumento = str(numerodoc)
+        self.TituloNossoNumero = None
+        self.TituloNumeroDocumento = None
         self.TituloValor = str(titulo['TituloValor'])
         dataemissao = titulo['TituloDataEmissao'].strftime('%d/%m/%Y')
         self.TituloDataEmissao = dataemissao
@@ -83,9 +81,10 @@ class Boleto(ObjectJSON):
         self.TituloCodigoReferencia = None
         self.TituloTipoCobranca = None
 
-    def update_return(self, r):
+    def update_return(self, r, body):
         dados = r.get('_dados') or {}
         sucesso = dados.get('_sucesso') or {}
+        self.body = body
         self.idintegracao = sucesso[0]['idintegracao']
         self.situacao = sucesso[0]['situacao']
         self.TituloNumeroDocumento = sucesso[0]['TituloNumeroDocumento']
