@@ -1,5 +1,6 @@
 
 from .base import Base
+import json
 
 class CriarBoleto(Base):
 
@@ -15,9 +16,11 @@ class CriarBoleto(Base):
 
         response = self.send_request("POST", uri, criar_boleto)
 
-        sucesso = response['_dados']['_sucesso']
+        body = response[1]
+        body = json.loads(json.dumps(body))
+        sucesso = response[0]['_dados']['_sucesso']
         if sucesso:
-            criar_boleto.update_return(response)
+            criar_boleto.update_return(response[0], body)
         else:
             return response['_dados']['_falha'][0]
 
